@@ -1,5 +1,5 @@
-# Example for: alignment.append(), alignment.write(),
-#              alignment.check()
+# Example for: Alignment.append(), Alignment.write(),
+#              Alignment.check()
 
 # Read an alignment, write it out in the 'PAP' format, and
 # check the alignment of the N-1 structures as well as the
@@ -8,10 +8,10 @@
 from modeller import *
 
 log.level(output=1, notes=1, warnings=1, errors=1, memory=0)
-env = environ()
+env = Environ()
 env.io.atom_files_directory = ['../atom_files']
 
-aln = alignment(env)
+aln = Alignment(env)
 aln.append(file='toxin.ali', align_codes='all')
 aln.write(file='toxin.pap', alignment_format='PAP')
 aln.write(file='toxin.fasta', alignment_format='FASTA')
